@@ -136,8 +136,10 @@ Change log
 ==========
 
 * 0.4:
+    * 0.4.2 (*2013-03-22*):
+        * Akismet settings made optional for non-Akismet users.
     * 0.4.1 (*2013-03-21*):
-        Bugfix at djangospam.akismet.
+        * Bugfix at djangospam.akismet.
     * 0.4.0 (*2013-03-20*):
         * Added cookie-based comment moderator.
         * Transformed Akismet module into a separate subpackage.
@@ -171,4 +173,4 @@ Change log
         * First version.
 """
 
-__version__ = "0.4.1"
\ No newline at end of file
+__version__ = "0.4.2"
\ No newline at end of file
